@@ -84,6 +84,9 @@ class PWMOut:
         if self._channel is None:
             raise RuntimeError("No PWM channel found for this Pin")
 
+        if variable_frequency:
+            print("Variable Frequency is not supported, continuing without it...")
+
         channel_path = os.path.join(
             self._sysfs_path, self._channel_path.format(self._channel)
         )
@@ -121,9 +124,6 @@ class PWMOut:
             channel_path = os.path.join(
                 self._sysfs_path, self._channel_path.format(self._channel)
             )
-            pin_path = os.path.join(
-                channel_path, self._pin_path.format(self._channel, self._pwmpin)
-            )
 
             if self._channel is not None:
                 # self.duty_cycle = 0
